==> hyades.source_1.3.0_20040422_2239.zip: org/eclipse/hyades/test/http/internal/reports/hitrate/HitRateReport.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.http.internal.reports.hitrate;

import java.util.Iterator;

import org.eclipse.hyades.models.common.testprofile.TPFExecutionResult;
import org.eclipse.hyades.models.common.testprofile.TPFExecutionType;
import org.eclipse.hyades.models.common.testprofile.TPFMessageEvent;
import org.eclipse.hyades.models.common.testprofile.TPFTypedEvent;
import org.eclipse.hyades.test.http.internal.reports.HttpAbstractReport;
import org.eclipse.hyades.test.http.internal.reports.responsetime.ResponseTimeReport;

/**
 * 
 * @author Ernest Jessee
 * @author jnevicos
 */
public class HitRateReport extends HttpAbstractReport
{
 
	protected long startTime=-1;
	protected long stopTime=-1;

	/**
	 * 
	 */
	public HitRateReport(TPFExecutionResult result) {
		super(result);
	}

	protected void finishReport()
	{
		if (list.size() > 1) //don't add overall if less than 2 elements
		{
			HitRateData.setTestElapsedTime(stopTime-startTime);
			list.add(new HitRateData.OverallHitRate());
		}
	}

	protected void setupReport() 
	{
		HitRateData.resetCounter();
	}
	
	protected void processMessageEvent(TPFMessageEvent event)
	{						
		String message = event.getText();
				
				
		int responseTimeIndex = message.indexOf(responseTimeMarker); 
		if(responseTimeIndex!=-1)
		{
			String pageName = message.substring(message.indexOf(pageNameMarker)+ResponseTimeReport.pageNameMarker.length(),responseTimeIndex).trim();
			String responseTime = message.substring(responseTimeIndex+responseTimeMarker.length(),message.length());
			responseTime=responseTime.substring(0,responseTime.indexOf(crlf)).trim();
					
					
			HitRateData hitRateData = (HitRateData) findPage(pageName);
			if(hitRateData==null)						
			{
				hitRateData = new HitRateData(pageName);
				list.add(hitRateData);
			}
			hitRateData.addHit(new Long(responseTime).longValue());				
		}
		
	}

	protected void processTypedEvent(TPFTypedEvent typedEvent)
	{
		if(typedEvent.getType()==TPFExecutionType.STOP_LITERAL)
		{
			stopTime = typedEvent.getTimestamp();
		}
		else if(startTime==-1)
		{
			startTime=typedEvent.getTimestamp();
		}						
	}



}

==> hyades.source_3.0.0_20040621_1225.zip: org/eclipse/hyades/test/http/internal/reports/hitrate/HitRateReport.java <==
/*******************************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.hyades.test.http.internal.reports.hitrate;

import java.util.Iterator;

import org.eclipse.hyades.models.common.testprofile.TPFExecutionResult;
import org.eclipse.hyades.models.common.testprofile.TPFExecutionType;
import org.eclipse.hyades.models.common.testprofile.TPFMessageEvent;
import org.eclipse.hyades.models.common.testprofile.TPFTypedEvent;
import org.eclipse.hyades.test.http.internal.reports.HttpAbstractReport;
import org.eclipse.hyades.test.http.internal.reports.responsetime.ResponseTimeReport;

/**
 * 
 * @author Ernest Jessee
 * @author jnevicos
 */
public class HitRateReport extends HttpAbstractReport
{
 
	protected long startTime=-1;
	protected long stopTime=-1;

	/**
	 * 
	 */
	public HitRateReport(TPFExecutionResult result) {
		super(result);
	}

	protected void finishReport()
	{
		if (list.size() > 1) //don't add overall if less than 2 elements
		{
			HitRateData.setTestElapsedTime(stopTime-startTime);
			list.add(new HitRateData.OverallHitRate());
		}
	}

	protected void setupReport() 
	{
		HitRateData.resetCounter();
	}
	
	protected void processMessageEvent(TPFMessageEvent event)
	{						
		String message = event.getText();
				
				
		int responseTimeIndex = message.indexOf(responseTimeMarker); 
		if(responseTimeIndex!=-1)
		{
			String pageName = message.substring(message.indexOf(pageNameMarker)+ResponseTimeReport.pageNameMarker.length(),responseTimeIndex).trim();
			String responseTime = message.substring(responseTimeIndex+responseTimeMarker.length(),message.length());
			responseTime=responseTime.substring(0,responseTime.indexOf(lf)).trim();
					
					
			HitRateData hitRateData = (HitRateData) findPage(pageName);
			if(hitRateData==null)						
			{
				hitRateData = new HitRateData(pageName);
				list.add(hitRateData);
			}
			hitRateData.addHit(new Long(responseTime).longValue());				
		}
		
	}

	protected void processTypedEvent(TPFTypedEvent typedEvent)
	{
		if(typedEvent.getType()==TPFExecutionType.STOP_LITERAL)
		{
			stopTime = typedEvent.getTimestamp();
		}
		else if(startTime==-1)
		{
			startTime=typedEvent.getTimestamp();
		}						
	}



}
